==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/RequestAbstractType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for RequestAbstractType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RequestAbstractType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}MessageAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ResponseMechanism" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RespondWith" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}PendingNotification" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="OriginalRequestId" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *       &lt;attribute name="ResponseLimit" type="{http://www.w3.org/2001/XMLSchema}integer" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RequestAbstractType", propOrder = {
    "responseMechanism",
    "respondWith",
    "pendingNotification"
})
@XmlSeeAlso({
    CompoundRequestType.class,
    PendingRequestType.class,
    LocateRequestType.class,
    ValidateRequestType.class,
    RegisterRequestType.class,
    ReissueRequestType.class,
    RevokeRequestType.class,
    RecoverRequestType.class
})
public abstract class RequestAbstractType
    extends MessageAbstractType
{

    @XmlElement(name = "ResponseMechanism")
    protected List<String> responseMechanism;
    @XmlElement(name = "RespondWith")
    protected List<String> respondWith;
    @XmlElement(name = "PendingNotification")
    protected PendingNotificationType pendingNotification;
    @XmlAttribute(name = "OriginalRequestId")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String originalRequestId;
    @XmlAttribute(name = "ResponseLimit")
    protected BigInteger responseLimit;

    /**
     * Gets the value of the responseMechanism property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the responseMechanism property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getResponseMechanism().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getResponseMechanism() {
        if (responseMechanism == null) {
            responseMechanism = new ArrayList<String>();
        }
        return this.responseMechanism;
    }

    /**
     * Gets the value of the respondWith property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the respondWith property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRespondWith().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    public List<String> getRespondWith() {
        if (respondWith == null) {
            respondWith = new ArrayList<String>();
        }
        return this.respondWith;
    }

    /**
     * Gets the value of the pendingNotification property.
     * 
     * @return
     *     possible object is
     *     {@link PendingNotificationType }
     *     
     */
    public PendingNotificationType getPendingNotification() {
        return pendingNotification;
    }

    /**
     * Sets the value of the pendingNotification property.
     * 
     * @param value
     *     allowed object is
     *     {@link PendingNotificationType }
     *     
     */
    public void setPendingNotification(PendingNotificationType value) {
        this.pendingNotification = value;
    }

    /**
     * Gets the value of the originalRequestId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOriginalRequestId() {
        return originalRequestId;
    }

    /**
     * Sets the value of the originalRequestId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOriginalRequestId(String value) {
        this.originalRequestId = value;
    }

    /**
     * Gets the value of the responseLimit property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getResponseLimit() {
        return responseLimit;
    }

    /**
     * Sets the value of the responseLimit property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setResponseLimit(BigInteger value) {
        this.responseLimit = value;
    }

}

==> cxf-services-xkms-common-4.1.1-sources.jar: org/apache/cxf/xkms/model/xkms/RequestAbstractType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for RequestAbstractType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="RequestAbstractType">
 *   <complexContent>
 *     <extension base="{http://www.w3.org/2002/03/xkms#}MessageAbstractType">
 *       <sequence>
 *         <element ref="{http://www.w3.org/2002/03/xkms#}ResponseMechanism" maxOccurs="unbounded" minOccurs="0"/>
 *         <element ref="{http://www.w3.org/2002/03/xkms#}RespondWith" maxOccurs="unbounded" minOccurs="0"/>
 *         <element ref="{http://www.w3.org/2002/03/xkms#}PendingNotification" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="OriginalRequestId" type="{http://www.w3.org/2001/XMLSchema}NCName" />
 *       <attribute name="ResponseLimit" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RequestAbstractType", propOrder = {
    "responseMechanism",
    "respondWith",
    "pendingNotification"
})
@XmlSeeAlso({
    CompoundRequestType.class,
    PendingRequestType.class,
    LocateRequestType.class,
    ValidateRequestType.class,
    RegisterRequestType.class,
    ReissueRequestType.class,
    RevokeRequestType.class,
    RecoverRequestType.class
})
public abstract class RequestAbstractType
    extends MessageAbstractType
{

    @XmlElement(name = "ResponseMechanism")
    protected List<String> responseMechanism;
    @XmlElement(name = "RespondWith")
    protected List<String> respondWith;
    @XmlElement(name = "PendingNotification")
    protected PendingNotificationType pendingNotification;
    @XmlAttribute(name = "OriginalRequestId")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String originalRequestId;
    @XmlAttribute(name = "ResponseLimit")
    protected BigInteger responseLimit;

    /**
     * Gets the value of the responseMechanism property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the responseMechanism property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getResponseMechanism().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * </p>
     * 
     * 
     * @return
     *     The value of the responseMechanism property.
     */
    public List<String> getResponseMechanism() {
        if (responseMechanism == null) {
            responseMechanism = new ArrayList<>();
        }
        return this.responseMechanism;
    }

    /**
     * Gets the value of the respondWith property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the respondWith property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getRespondWith().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * </p>
     * 
     * 
     * @return
     *     The value of the respondWith property.
     */
    public List<String> getRespondWith() {
        if (respondWith == null) {
            respondWith = new ArrayList<>();
        }
        return this.respondWith;
    }

    /**
     * Gets the value of the pendingNotification property.
     * 
     * @return
     *     possible object is
     *     {@link PendingNotificationType }
     *     
     */
    public PendingNotificationType getPendingNotification() {
        return pendingNotification;
    }

    /**
     * Sets the value of the pendingNotification property.
     * 
     * @param value
     *     allowed object is
     *     {@link PendingNotificationType }
     *     
     */
    public void setPendingNotification(PendingNotificationType value) {
        this.pendingNotification = value;
    }

    /**
     * Gets the value of the originalRequestId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOriginalRequestId() {
        return originalRequestId;
    }

    /**
     * Sets the value of the originalRequestId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOriginalRequestId(String value) {
        this.originalRequestId = value;
    }

    /**
     * Gets the value of the responseLimit property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getResponseLimit() {
        return responseLimit;
    }

    /**
     * Sets the value of the responseLimit property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setResponseLimit(BigInteger value) {
        this.responseLimit = value;
    }

}
